#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio
version:              0.1.20.0
visibility:           public
id:                   rio-0.1.20.0-LPBfpbY87JCMYrSVKFBdH
key:                  rio-0.1.20.0-LPBfpbY87JCMYrSVKFBdH
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>

category:             Control
abi:                  a930307b20813545c0d02f959b7c21c6
exposed:              True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.Lens RIO.List RIO.List.Partial RIO.Map
    RIO.Map.Partial RIO.Map.Unchecked RIO.NonEmpty RIO.NonEmpty.Partial
    RIO.Partial RIO.Prelude RIO.Prelude.Simple RIO.Prelude.Types
    RIO.Process RIO.Seq RIO.Set RIO.Set.Partial RIO.Set.Unchecked
    RIO.State RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer

hidden-modules:
    RIO.Prelude.Display RIO.Prelude.Exit RIO.Prelude.Extra
    RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
    RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
    RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef

import-dirs:          /usr/lib/ghc-8.10.5/site-local/rio-0.1.20.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/rio-0.1.20.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/rio-0.1.20.0
hs-libraries:         HSrio-0.1.20.0-LPBfpbY87JCMYrSVKFBdH
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    deepseq-1.4.4.0 directory-1.3.6.0 exceptions-0.10.4
    filepath-1.4.2.1 hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    microlens-0.4.12.0-7mbtYeVEJj9DE2AV66WaoK
    microlens-mtl-0.2.0.1-JgTbTlYIvEKBoII676UfjM mtl-2.2.2
    primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh process-1.6.9.0
    text-1.2.4.1 time-1.9.3
    typed-process-0.2.6.0-Gc1yegq45YvGrDlijuOTah unix-2.7.2.2
    unliftio-0.2.18-2kiHcgI4qdj1XlC6DQIVT2
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html:         /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

